package com.ruoyi.project.business.service.quotation;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.business.domain.TbSalesDiscount;
import com.ruoyi.project.business.domain.TqQuotation;
import com.ruoyi.project.business.domain.bo.quotation.QuotationAddBO;
import com.ruoyi.project.business.domain.bo.quotation.QuotationCopyBO;
import com.ruoyi.project.business.domain.bo.quotation.QuotationQueryBO;
import com.ruoyi.project.business.domain.flow.FlowAuditParam;
import com.ruoyi.project.business.domain.vo.quotation.QuotationDetailVO;
import com.ruoyi.project.business.domain.vo.quotation.QuotationExportVO;
import com.ruoyi.project.business.domain.vo.quotation.QuotationPriceVO;
import com.ruoyi.project.business.domain.vo.quotation.QuotationVO;
import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2024-05-10
 */
public interface ITqQuotationService extends IService<TqQuotation> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public QuotationDetailVO selectTqQuotationById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqQuotation 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<QuotationVO> selectTqQuotationList(QuotationQueryBO tqQuotation);

    /**
     * 新增【请填写功能名称】
     *
     * @param tqQuotation 【请填写功能名称】
     * @return 结果
     */
    public void insertTqQuotation(QuotationAddBO quotationAddBO);

    /**
     * 修改【请填写功能名称】
     *
     * @param tqQuotation 【请填写功能名称】
     * @return 结果
     */
    public void updateTqQuotation(QuotationAddBO tqQuotation);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTqQuotationByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTqQuotationById(Long id);

    void copyVersions(QuotationCopyBO copyBO);

    List<QuotationVO> listByProjectId(Long projectId);

    void changeQuotationStatus(FlowAuditParam auditParam);

    List<QuotationExportVO> listExportVO(QuotationQueryBO queryBO);

    QuotationPriceVO getPriceInfo(Long quotationId);

    void changeBargainStatus(FlowAuditParam auditParam);

    TbSalesDiscount getSalesDiscountByQuotationId(Long quotationId);
}
